﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.SignalR;
using Microsoft.EntityFrameworkCore;
using VCinemaApi.Models;
using VCinemaApi.Repositories;

namespace VCinemaApi.Hubs
{
    public class VCinemaHub : Hub<IVCinemaHub>
    {
        private readonly IScreenRepository _screenRepository;
        private readonly IWatcherRepository _watcherRepository;

        public VCinemaHub(IScreenRepository screenRepository, IWatcherRepository watcherRepository)
        {
            _screenRepository = screenRepository;
            _watcherRepository = watcherRepository;
        }

        public override async Task OnConnectedAsync()
        {
            _watcherRepository.AddWatcher(Context.ConnectionId);
            await base.OnConnectedAsync();
        }

        public override async Task OnDisconnectedAsync(Exception exception)
        {
            _watcherRepository.DeleteWatcher(Context.ConnectionId);
            await base.OnDisconnectedAsync(exception);
        }

        public IEnumerable<Screen> GetScreens()
        {
            return _screenRepository.GetScreens();
        }

        public Screen GetScreenById(int screenId)
        {
            return _screenRepository.GetScreenById(screenId);
        }
    }
}
